OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoritter",
    "No file provided for import" : "Ingen fil til import",
    "Unsupported file type for import" : "Denne filtype er ikke understøttet til import",
    "A Bookmark manager for Nextcloud" : "En app til at administrere bogmærker i Nextcloud",
    "Select bookmark" : "Vælg bogmærke",
    "Details" : "Detaljer",
    "Rename" : "Omdøb",
    "Move" : "Flyt",
    "Delete" : "Slet",
    "Move selection" : "Flyt valgte",
    "Delete selection" : "Slet valgte",
    "Select all" : "Vælg alle",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valgt %n bogmærke","Valgt %n bogmærker"],
    "Select one or more tags" : "Vælg et eller flere tags",
    "New" : "Ny",
    "New folder" : "Ny mappe",
    "Enter a link" : "Indtast et link",
    "Enter folder title" : "Angiv folder navn",
    "Submit" : "Tilføj",
    "Cancel" : "Annullér",
    "_Moving %n folder_::_Moving %n folders_" : ["Flytter %n mappe","Flytter %n mapper"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flytter %n bogmærke","Flytter %n bogmærker"],
    "All bookmarks" : "Alle bogmærker",
    "Recent" : "Seneste",
    "Untagged" : "Fravalgt",
    "Import" : "Importér",
    "Export" : "Eksportér",
    "Client apps" : "Klient apps",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName}" : "Tilføj til {instanceName}",
    "Clear data" : "Fjern data",
    "Delete all bookmarks" : "Slet alle bogmærker",
    "Do you really want to delete all your bookmarks?" : "Ønsker du virkelig at slette alle dine bogmærker?",
    "Title" : "Titel",
    "Link" : "Link",
    "Tags" : "Mærker",
    "Notes" : "Noter",
    "Owner" : "Ejer",
    "Sharing" : "Deling",
    "Share link" : "Share link",
    "Copy link" : "Kopiér link",
    "Allow editing" : "Tillad redigering",
    "Link copied" : "Link kopieret",
    "Privacy" : "Privatliv",
    "Performance" : "Ydelse",
    "Previews" : "Forhåndsvisning",
    "Screeenly" : "Screeenly",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API nøgle",
    "Failed to load settings" : "Fejl ved indlæsning af indstillinger",
    "Failed to save settings" : "Kunne ikke gemme indstillinger",
    "Add a bookmark" : "Tilføj et bogmærke",
    "This URL is already bookmarked! Overwrite?" : "Denne URL har allerede et bogmærke. Overskriv?",
    "Enter bookmark title" : "Angiv titel på bogmærke",
    "Folder" : "Mappe",
    "Save" : "Gem",
    "Failed to find existing bookmark" : "Kunne ikke finde eksisterende bogmærke",
    "Failed to create bookmark" : "Kunne ikke oprette bogmærke",
    "Failed to save bookmark" : "Kunne ikke gemme bogmærke",
    "Failed to move bookmark" : "Kunne ikke flytte bogmærke",
    "Failed to delete bookmark" : "Kunne ikke slette bogmærke",
    "Failed to load tags" : "Kunne ikke indlæse tags.",
    "Failed to load folders" : "Fejl ved indlæsning af mapper",
    "Failed to delete folder" : "Fejl ved sletning af mappe",
    "Failed to create folder" : "Fejl ved opretning af mappe",
    "Failed to fetch bookmarks." : "Fejl ved indlæsning af bogmærker.",
    "Failed to change setting" : "Fejl ved ændring af indstilling",
    "Bookmarks feed" : "Bogmærkestrøm"
},
"nplurals=2; plural=(n != 1);");
